ipset

package
v0.8.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Set

type Set struct {
	// contains filtered or unexported fields
}

Set represents an ipset. Set can safely be used concurrently.

func New

func New(name string) *Set

New generates a new ipset.

func (*Set) CleanUp

func (s *Set) CleanUp() error

CleanUp will clean up any hosts added to the set.

func (*Set) Run

func (s *Set) Run(stop <-chan struct{}) (<-chan error, error)

Run watches for changes to the ipset and reconciles the ipset against the desired state.

func (*Set) Set

func (s *Set) Set(hosts []net.IP) error

Set idempotently overwrites any hosts previously defined for the ipset with the given hosts.

Jump to